==> asr_business-0.1.9.4.tar.gz: asr_business-0.1.9.4/src/asr_business/vad.py <==
import multiprocessing
from concurrent.futures import ProcessPoolExecutor

import psutil
import torch
from funasr_onnx import Fsmn_vad

torch.set_num_threads(1)
vad_models = dict()


class Vad:
    def __init__(self, vad_model_path, num_process=0, batch_size=40):
        """
        vad_model_path: vad模型路径
        batch_size: 返回时的batch_size
        num_process: 进程数量
        """
        self.batch_size = batch_size
        self.vad_model = Fsmn_vad(vad_model_path)
        self.executor = ProcessPoolExecutor(
            max_workers=self.get_optimal_workers() if num_process == 0 else num_process,
            initializer=self.init_model,
            initargs=(self.vad_model,)
        )

    def __del__(self):
        """
        析构函数，确保进程池正确关闭
        """
        if hasattr(self, 'executor'):
            self.executor.shutdown()

    @staticmethod
    def init_model(model):
        """
        初始化模型
        :param model: 模型实例
        :return:
        """
        pid = multiprocessing.current_process().pid
        vad_models[pid] = model

    @staticmethod
    def vad_process(audio_file):
        """
        vad处理音频文件
        :param audio_file: 音频文件
        :return:
        """
        pid = multiprocessing.current_process().pid
        return vad_models[pid](audio_file)

    @staticmethod
    def get_optimal_workers():
        """
        动态获取workers节点数
        :return:
        """
        cpu_count = psutil.cpu_count()
        cpu_percent = psutil.cpu_percent(interval=1)
        if cpu_percent > 65:
            return cpu_count // 4
        return cpu_count // 2

    def silence_detection(self, audios):
        """
        使用已存在的进程池对音频文件进行静音检测
        :param audios: 音频文件列表
        :return: 静音文件结果 及 有效文件（非静音、以.mp3为后缀）列表
        """
        valid_audios = []
        tmp_ls = []
        futures = []
        if not audios:
            raise ValueError("audios list can't be empty")
        for input_file in audios:
            futures.append([input_file, self.executor.submit(self.vad_process, input_file)])
        for finish in futures:
            if finish[1].result()[0] and finish[0].endswith(".mp3"):
                valid_audios.append(finish[0])
            else:
                tmp_ls.append({"key": finish[0], "text": ""})
        res_ls = [tmp_ls[i:i + self.batch_size] for i in range(0, len(tmp_ls), self.batch_size)]
        return valid_audios, res_ls

==> asr_business-0.2.2.tar.gz: asr_business-0.2.2/src/asr_business/vad.py <==
import multiprocessing
from concurrent.futures import ProcessPoolExecutor

import psutil
import torch
from funasr_onnx import Fsmn_vad
import os

torch.set_num_threads(1)
vad_models = dict()


class Vad:
    def __init__(self, vad_model_path, num_process=0, batch_size=40):
        """
        vad_model_path: vad模型路径
        batch_size: 返回时的batch_size
        num_process: 进程数量
        """
        self.batch_size = batch_size
        self.vad_model = Fsmn_vad(vad_model_path)
        self.executor = ProcessPoolExecutor(
            max_workers=self.get_optimal_workers() if num_process == 0 else num_process,
            initializer=self.init_model,
            initargs=(self.vad_model,)
        )

    def __del__(self):
        """
        析构函数，确保进程池正确关闭
        """
        if hasattr(self, 'executor'):
            self.executor.shutdown()

    @staticmethod
    def init_model(model):
        """
        初始化模型
        :param model: 模型实例
        :return:
        """
        pid = multiprocessing.current_process().pid
        vad_models[pid] = model

    @staticmethod
    def vad_process(audio_file):
        """
        vad处理音频文件
        :param audio_file: 音频文件
        :return:
        """
        pid = multiprocessing.current_process().pid
        return vad_models[pid](audio_file)

    @staticmethod
    def get_optimal_workers():
        """
        动态获取workers节点数
        :return:
        """
        cpu_count = psutil.cpu_count()
        cpu_percent = psutil.cpu_percent(interval=1)
        if cpu_percent > 65:
            return cpu_count // 4
        return cpu_count // 2

    def silence_detection(self, audios):
        """
        使用已存在的进程池对音频文件进行静音检测
        :param audios: 音频文件列表
        :return: 静音文件结果 及 有效文件（非静音、以.mp3为后缀）列表
        """
        valid_audios = []
        tmp_ls = []
        futures = []
        if not audios:
            raise ValueError("vad in progress, audios list can't be empty")
        for input_file in audios:
            futures.append([input_file, self.executor.submit(self.vad_process, input_file)])
        for finish in futures:
            if finish[1].result()[0] and finish[0].endswith(".mp3"):
                valid_audios.append(finish[0])
            else:
                tmp_ls.append({"key": os.path.basename(finish[0]).split(".")[0], "text": ""})
        res_ls = [tmp_ls[i:i + self.batch_size] for i in range(0, len(tmp_ls), self.batch_size)]
        return valid_audios, res_ls
